@@ -14,12 +14,15 @@ __email__ = "guill.p.linux@gmail.com"
 
 from .enums import EncryptionAlgs, KeyManagementAlgs, SignatureAlgs
 from .jwa import (
+    A128CBC_HS256,
     A128GCM,
     A128GCMKW,
     A128KW,
+    A192CBC_HS384,
     A192GCM,
     A192GCMKW,
     A192KW,
+    A256CBC_HS512,
     A256GCM,
     A256GCMKW,
     A256KW,
@@ -41,9 +44,6 @@ from .jwa import (
     RS512,
     X448,
     X25519,
-    Aes128CbcHmacSha256,
-    Aes192CbcHmacSha384,
-    Aes256CbcHmacSha512,
     BaseAESEncryptionAlg,
     BaseAlg,
     BaseAsymmetricAlg,
@@ -62,6 +62,7 @@ from .jwa import (
     Ed25519,
     EdDsa,
     EllipticCurve,
+    MismatchingAuthTag,
     OKPCurve,
     Pbes2_HS256_A128KW,
     Pbes2_HS384_A192KW,
@@ -91,7 +92,6 @@ from .jwk import (
 )
 from .jws import InvalidJws, JwsCompact
 from .jwt import (
-    EncryptedJwt,
     ExpiredJwt,
     InvalidClaim,
     InvalidJwt,
@@ -132,9 +132,9 @@ __all__ = [
     "RS512",
     "X448",
     "X25519",
-    "Aes128CbcHmacSha256",
-    "Aes192CbcHmacSha384",
-    "Aes256CbcHmacSha512",
+    "A128CBC_HS256",
+    "A192CBC_HS384",
+    "A256CBC_HS512",
     "BaseAESEncryptionAlg",
     "BaseAlg",
     "BaseAsymmetricAlg",
@@ -153,6 +153,7 @@ __all__ = [
     "Ed25519",
     "EdDsa",
     "EllipticCurve",
+    "MismatchingAuthTag",
     "OKPCurve",
     "Pbes2_HS256_A128KW",
     "Pbes2_HS384_A192KW",
@@ -180,7 +181,6 @@ __all__ = [
     "UnsupportedOKPCurve",
     "InvalidJws",
     "JwsCompact",
-    "EncryptedJwt",
     "ExpiredJwt",
     "InvalidClaim",
     "InvalidJwt",
