@@ -1,4 +1,5 @@
 """This module implements AES based Key Management algorithms."""
+from typing import SupportsBytes, Union
 
 from binapy import BinaPy
 from cryptography.hazmat.primitives import keywrap
@@ -38,7 +39,7 @@ class BaseAesKeyWrap(BaseKeyManagementAlg, BaseSymmetricAlg):
         """
         return BinaPy(keywrap.aes_key_wrap(self.key, plainkey))
 
-    def unwrap_key(self, cipherkey: bytes) -> BinaPy:
+    def unwrap_key(self, cipherkey: Union[bytes, SupportsBytes]) -> BinaPy:
         """Unwrap a key.
 
         Args:
@@ -47,6 +48,9 @@ class BaseAesKeyWrap(BaseKeyManagementAlg, BaseSymmetricAlg):
         Returns:
           BinaPy: the unwrapped key.
         """
+        if not isinstance(cipherkey, bytes):
+            cipherkey = bytes(cipherkey)
+
         return BinaPy(keywrap.aes_key_unwrap(self.key, cipherkey))
 
 
