@@ -1,6 +1,6 @@
 """This module implements the Edwards-curve Digital Signature Algorithm (EdDSA)."""
 
-from typing import Union
+from typing import SupportsBytes, Union
 
 from binapy import BinaPy
 from cryptography import exceptions
@@ -24,11 +24,21 @@ class EdDsa(
     name = "EdDSA"
     description = __doc__
 
-    def sign(self, data: bytes) -> BinaPy:  # noqa: D102
+    def sign(self, data: Union[bytes, SupportsBytes]) -> BinaPy:  # noqa: D102
+        if not isinstance(data, bytes):
+            data = bytes(data)
+
         with self.private_key_required() as key:
             return BinaPy(key.sign(data))
 
-    def verify(self, data: bytes, signature: bytes) -> bool:  # noqa: D102
+    def verify(
+        self, data: Union[bytes, SupportsBytes], signature: Union[bytes, SupportsBytes]
+    ) -> bool:  # noqa: D102
+        if not isinstance(data, bytes):
+            data = bytes(data)
+        if not isinstance(signature, bytes):
+            signature = bytes(signature)
+
         with self.public_key_required() as key:
             try:
                 key.verify(signature, data)
