@@ -1,7 +1,7 @@
 """This module implements the JWE Compact format."""
 
 import warnings
-from typing import Any, Dict, Mapping, Optional, Type, Union
+from typing import Any, Dict, Mapping, Optional, SupportsBytes, Type, Union
 
 from backports.cached_property import cached_property
 from binapy import BinaPy
@@ -13,7 +13,7 @@ from jwskate.jwa import (
     Pbes2_HS512_A256KW,
 )
 from jwskate.jwk import Jwk, SymmetricJwk
-from jwskate.jwk.alg import UnsupportedAlg
+from jwskate.jwk.alg import UnsupportedAlg, select_alg
 from jwskate.token import BaseCompactToken
 
 
@@ -131,7 +131,7 @@ class JweCompact(BaseCompactToken):
     @classmethod
     def encrypt(
         cls,
-        plaintext: bytes,
+        plaintext: Union[bytes, SupportsBytes],
         jwk: Union[Jwk, Dict[str, Any]],
         *,
         enc: str,
@@ -141,12 +141,12 @@ class JweCompact(BaseCompactToken):
         iv: Optional[bytes] = None,
         epk: Optional[Jwk] = None,
     ) -> "JweCompact":
-        """Encrypt an arbitrary plaintext and return the resulting JweCompact.
+        """Encrypt an arbitrary plaintext into a JweCompact.
 
         Args:
           plaintext: the raw plaintext to encrypt
-          jwk: the public or symmetric key to use
-          enc: the CEK encryption algorithm to use
+          jwk: the public or symmetric key to use for encryption
+          enc: the encryption algorithm to use
           alg: the Key Management algorithm to use, if there is no 'alg' header defined in the Jwk
           extra_headers: additional headers to include in the generated token
           cek: the CEK to force use, for algorithms relying on a random CEK. Leave `None` to have a safe value generated by `jwskate`.
@@ -156,13 +156,19 @@ class JweCompact(BaseCompactToken):
         Returns:
             the generated JweCompact instance
         """
-        jwk = Jwk(jwk)
         extra_headers = extra_headers or {}
+        if not isinstance(jwk, Jwk):
+            jwk = Jwk(jwk)
+        alg = select_alg(jwk.alg, alg, jwk.KEY_MANAGEMENT_ALGORITHMS).name
+
         cek_jwk, wrapped_cek, cek_headers = jwk.sender_key(
             enc=enc, alg=alg, cek=cek, epk=epk, **extra_headers
         )
 
         headers = dict(extra_headers, **cek_headers, alg=alg, enc=enc)
+        if jwk.kid is not None:
+            headers["kid"] = jwk.kid
+
         aad = BinaPy.serialize_to("json", headers).to("b64u")
 
         ciphertext, iv, tag = cek_jwk.encrypt(plaintext, aad=aad, iv=iv, alg=enc)
@@ -198,14 +204,14 @@ class JweCompact(BaseCompactToken):
     def decrypt(
         self,
         jwk: Union[Jwk, Dict[str, Any]],
-    ) -> bytes:
+    ) -> BinaPy:
         """Decrypts this Jwe payload using a JWK.
 
         Args:
           jwk: the decryption key
 
         Returns:
-          bytes: the decrypted payload
+          the decrypted payload
         """
         cek_jwk = self.unwrap_cek(jwk)
 
@@ -221,8 +227,8 @@ class JweCompact(BaseCompactToken):
     @classmethod
     def encrypt_with_password(
         cls,
-        plaintext: bytes,
-        password: Union[bytes, str],
+        plaintext: Union[SupportsBytes, bytes],
+        password: Union[SupportsBytes, bytes, str],
         *,
         alg: str,
         enc: str,
