@@ -1,14 +1,12 @@
 """This module contains all Json Web Key (Jwk) related classes and utilities."""
 
 from .base import InvalidJwt, Jwt
-from .encrypted import EncryptedJwt
 from .signed import ExpiredJwt, InvalidClaim, InvalidSignature, SignedJwt
 from .signer import JwtSigner
 
 __all__ = [
     "Jwt",
     "InvalidJwt",
-    "EncryptedJwt",
     "ExpiredJwt",
     "InvalidClaim",
     "InvalidSignature",
