@@ -2,16 +2,17 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, Iterable, Optional, Union
 
 from binapy import BinaPy
 
+from jwskate.jwe import JweCompact
 from jwskate.jwk import Jwk
 
 from ..token import BaseCompactToken
 
 if TYPE_CHECKING:
-    from jwskate import EncryptedJwt, SignedJwt  # pragma: no cover
+    from jwskate import SignedJwt  # pragma: no cover
 
 
 class InvalidJwt(ValueError):
@@ -22,7 +23,9 @@ class Jwt(BaseCompactToken):
     """Represents a Json Web Token."""
 
     def __new__(cls, value: Union[bytes, str]):  # type: ignore
-        """Allow parsing both Signed and Encrypted JWTs. Returns the appropriate subclass instance.
+        """Allow parsing both Signed and Encrypted JWTs.
+
+        This returns the appropriate subclass or instance depending on the number of dots (.) in the serialized JWT.
 
         Args:
             value: the token value
@@ -35,10 +38,10 @@ class Jwt(BaseCompactToken):
                 from .signed import SignedJwt
 
                 return super().__new__(SignedJwt)
-            elif value.count(b".") == 3:
-                from .encrypted import EncryptedJwt
+            elif value.count(b".") == 4:
+                from ..jwe import JweCompact
 
-                return super().__new__(EncryptedJwt)
+                return JweCompact(value)
         return super().__new__(cls)
 
     @classmethod
@@ -68,15 +71,14 @@ class Jwt(BaseCompactToken):
         jwk = Jwk(jwk)
 
         alg = alg or jwk.get("alg")
-        kid = jwk.get("kid")
 
         if alg is None:
             raise ValueError("a signing alg is required")
 
         extra_headers = extra_headers or {}
         headers = dict(alg=alg, **extra_headers)
-        if kid:
-            headers["kid"] = kid
+        if jwk.kid:
+            headers["kid"] = jwk.kid
 
         headers_part = BinaPy.serialize_to("json", headers).to("b64u")
         claims_part = BinaPy.serialize_to("json", claims).to("b64u")
@@ -114,24 +116,100 @@ class Jwt(BaseCompactToken):
         cls,
         claims: Dict[str, Any],
         sign_jwk: Union[Jwk, Dict[str, Any]],
-        sign_alg: Optional[str],
         enc_jwk: Union[Jwk, Dict[str, Any]],
-        enc_alg: Optional[str],
-        enc: Optional[str],
-    ) -> "EncryptedJwt":
-        """Sign then encrypt a payload with a `Jwk` and returns the resulting `EncryptedJwt`.
+        enc: str,
+        *,
+        sign_alg: Optional[str] = None,
+        enc_alg: Optional[str] = None,
+        sign_extra_headers: Optional[Dict[str, Any]] = None,
+        enc_extra_headers: Optional[Dict[str, Any]] = None,
+    ) -> JweCompact:
+        """Sign a JWT, then encrypt it as JWE payload.
 
-        NOT IMPLEMENTED YET.
+        This is a convenience method to do both the signing and encryption, in appropriate order.
 
         Args:
           claims: the payload to encrypt
           sign_jwk: the Jwk to use for signature
           sign_alg: the alg to use for signature
+          sign_extra_headers: additional headers for the inner signed JWT
           enc_jwk: the Jwk to use for encryption
           enc_alg: the alg to use for CEK encryption
           enc: the alg to use for payload encryption
+          enc_extra_headers: additional headers for the outer encrypted JWE
 
         Returns:
-          the resulting JWE token, with signed JWT as payload
+          the resulting JWE token, with the signed JWT as payload
         """
-        raise NotImplementedError
+        enc_extra_headers = enc_extra_headers or {}
+        enc_extra_headers.setdefault("cty", "JWT")
+
+        inner_jwt = cls.sign(
+            claims, jwk=sign_jwk, alg=sign_alg, extra_headers=sign_extra_headers
+        )
+        jwe = JweCompact.encrypt(
+            inner_jwt, enc_jwk, enc=enc, alg=enc_alg, extra_headers=enc_extra_headers
+        )
+        return jwe
+
+    @classmethod
+    def decrypt_nested_jwt(
+        cls, jwe: Union[str, JweCompact], jwk: Union[Jwk, Dict[str, Any]]
+    ) -> Jwt:
+        """Convenience method to decrypt a nested JWT.
+
+        It will return a Jwt instance.
+
+        Args:
+            jwt: the JWE containing a nested Token
+            jwk: the decryption key
+
+        Returns:
+            the inner token
+
+        Raises:
+            InvalidJwt: if the inner JWT is not valid
+        """
+        if not isinstance(jwe, JweCompact):
+            jwe = JweCompact(jwe)
+        cleartext = jwe.decrypt(jwk)
+        return Jwt(cleartext)
+
+    @classmethod
+    def decrypt_and_verify(
+        cls,
+        jwt: Union[str, JweCompact],
+        enc_jwk: Union[Jwk, Dict[str, Any]],
+        sig_jwk: Union[Jwk, Dict[str, Any], None],
+        sig_alg: Optional[str] = None,
+        sig_algs: Optional[Iterable[str]] = None,
+    ) -> SignedJwt:
+        """Decrypt then verify the signature of a JWT nested in a JWE.
+
+        This can only be used with signed then encrypted Jwt, such as those produce by `Jwt.sign_and_encrypt()`.
+
+        Args:
+            jwt: the JWE containing a nested signed JWT
+            enc_jwk: the decryption key
+            sig_jwk: the signature verification key
+            sig_alg: the signature verification alg, if only 1 is allowed
+            sig_algs: the signature verifications algs, if several are allowed
+
+        Returns:
+            the nested signed JWT, in clear-text, signature already verified
+
+        Raises:
+            InvalidJwt: if the JWT is not valid
+            InvalidSignature: if the nested JWT signature is not valid
+        """
+        from .signed import InvalidSignature, SignedJwt
+
+        nested_jwt = cls.decrypt_nested_jwt(jwt, enc_jwk)
+        if not isinstance(nested_jwt, SignedJwt):
+            raise ValueError("Nested JWT is not signed", nested_jwt)
+
+        if sig_jwk:
+            if nested_jwt.verify_signature(sig_jwk, sig_alg, sig_algs):
+                return nested_jwt
+
+        raise InvalidSignature()
